@@ -57,106 +57,51 @@ def vmom_proj(x1, y1, inc,
     z1 = scale*np.sinh(t)
     dxdt = dt*scale*np.cosh(t)
 
-    # Initializes moment values for interpolation
+    # Initialize moment values for interpolation
     irp = mom_interp(x1, y1,
                      dens_lum, sigma_lum, qintr_lum,
                      dens_pot, sigma_pot, qintr_pot,
                      beta, gamma, nrad, nang, epsrel,
                      rmin=np.min(sigma_lum)/3, rmax=rmax, align=align)
 
-    surf = np.empty(x1.size)
-    vel = np.empty((x1.size, 3))
-    vel2 = np.empty((x1.size, 3, 3))
+    x = x1[:, None]
+    y = z1*np.sin(inc) + y1[:, None]*np.cos(inc)                    # C20 eq.(29)
+    z = z1*np.cos(inc) - y1[:, None]*np.sin(inc)
+    R = np.sqrt(x**2 + y**2)
+    r = np.sqrt(R**2 + z**2)
+    cos_phi, sin_phi, sin_th, cos_th = x/R, y/R, R/r, z/r           # C20 eq.(30)
 
-    sin_i, cos_i = np.sin(inc), np.cos(inc)
+    mom = irp.get_moments(R.ravel(), z.ravel())
+    sig2r, sig2th, sig2phi, v2phi, nu = np.reshape(mom, (5,) + z.shape)
+    vphi = np.sqrt((v2phi - sig2phi).clip(0))
+    diag = np.array([sig2r, sig2th, v2phi])
+    zero = np.zeros_like(nu)
+    one = np.ones_like(nu)
 
-    for j, (x1j, y1j) in enumerate(zip(x1, y1)):
+    if align == 'cyl':
+        R = np.array([[cos_phi, zero, -sin_phi],
+                      [sin_phi, zero, cos_phi],                     # C20 eq.(24)
+                      [zero,    one,  zero]])                       # swap 2<->3 columns
+    else:  # align == 'sph'
+        R = np.array([[sin_th*cos_phi, cos_th*cos_phi, -sin_phi],
+                      [sin_th*sin_phi, cos_th*sin_phi, cos_phi],    # C20 eq.(16)
+                      [cos_th,         -sin_th,        zero]])
 
-        x = x1j
-        y = z1*sin_i + y1j*cos_i
-        z = z1*cos_i - y1j*sin_i
-        R = np.sqrt(x**2 + y**2).clip(1)  # clip to 1pc
-        r = np.sqrt(R**2 + z**2).clip(1)
+    S = np.array([[1,          0,            0],
+                  [0, np.cos(inc), -np.sin(inc)],                   # C20 eq.(17)
+                  [0, np.sin(inc), np.cos(inc)]])
 
-        sig2r, sig2th, sig2phi, v2phi, nu = irp.get_moments(R, z)
-        vphi = np.sqrt((v2phi - sig2phi).clip(0))
+    Q = np.einsum('ij,jkml->ikml', S, R)
+    integ1 = vphi*Q[:, 2]                                           # C20 eq.(21)
+    integ2 = np.einsum('jiml,kiml,iml->jkml', Q, Q, diag)           # C20 eq.(22)
 
-        diag = np.array([sig2r, sig2th, v2phi])
-        cos_phi, sin_phi, sin_th, cos_th = x/R, y/R, R/r, z/r   # C20 eq.(30)
+    surf = nu @ dxdt                # DE quadrature
+    nu_vlos = nu*integ1 @ dxdt      # DE quadrature
+    nu_v2rms = nu*integ2 @ dxdt     # DE quadrature
+    vel = nu_vlos/surf
+    vel2 = nu_v2rms/surf
 
-        # C20 eq.(17)
-        S = np.array([[1, 0,     0],
-                      [0, cos_i, -sin_i],
-                      [0, sin_i, cos_i]])
-
-        zero = np.zeros_like(z)
-        one = np.ones_like(z)
-
-        if align == 'cyl':
-
-            # C20 eq.(24)    swap 2<->3 columns
-            R = np.array([[cos_phi, zero, -sin_phi],
-                          [sin_phi, zero, cos_phi],
-                          [zero,    one,  zero]])
-
-        else:
-
-            # C20 eq.(16)
-            R = np.array([[sin_th*cos_phi, cos_th*cos_phi, -sin_phi],
-                          [sin_th*sin_phi, cos_th*sin_phi, cos_phi],
-                          [cos_th,         -sin_th,        zero]])
-
-        Q = np.einsum('ij,jkm->ikm', S, R)
-        integ1 = vphi*Q[:, 2]                              # C20 eq.(21)
-        integ2 = np.einsum('jim,kim,im->jkm', Q, Q, diag)  # C20 eq.(22)
-
-        surf[j] = nu @ dxdt            # DE quadrature
-        nu_vlos = nu*integ1 @ dxdt     # DE quadrature
-        nu_v2rms = nu*integ2 @ dxdt    # DE quadrature
-        vel[j] = nu_vlos/surf[j]
-        vel2[j] = nu_v2rms/surf[j]
-
-    return vel, vel2, surf
-
-##############################################################################
-
-def proj_model(x_pol, y_pol, inc,
-               dens_lum, sigma_lum, qintr_lum,
-               dens_pot, sigma_pot, qintr_pot,
-               beta, gamma, kappa, nrad, nang, nlos, epsrel, moment, align):
-    """
-    Returns a component of the second velocity moment tensor or the first
-    velocity moment, for either the spherically-aligned or cylindrically-aligned
-    JAM depending on the input parameters `moment` and `align`
-
-    """
-    # This procedure could be easily modified to return all moments simultaneaoulsy if useful.
-    # Right now, all the moments are computed and only one is retained, for clarity over speed.
-    
-    vel, vel2, mge = vmom_proj(x_pol, y_pol, inc,
-                               dens_lum, sigma_lum, qintr_lum,
-                               dens_pot, sigma_pot, qintr_pot,
-                               beta, gamma, nrad, nang, nlos, epsrel, align)
-    if moment == 'xx':
-        model = vel2[:, 0, 0]
-    elif moment == 'yy':
-        model = vel2[:, 1, 1]
-    elif moment == 'zz':
-        model = vel2[:, 2, 2]
-    elif moment == 'xy':
-        model = vel2[:, 0, 1]
-    elif moment == 'xz':
-        model = vel2[:, 0, 2]
-    elif moment == 'yz':
-        model = vel2[:, 1, 2]
-    elif moment == 'x':
-        model = vel[:, 0]
-    elif moment == 'y':
-        model = vel[:, 1]
-    elif moment == 'z':
-        model = vel[:, 2]
-
-    return model
+    return vel, vel2
 
 ##############################################################################
 
@@ -188,7 +133,7 @@ def bilinear_interpolate(xv, yv, im, xout, yout):
 
 def rotate_points(x, y, ang):
     """
-    Rotates points conter-clockwise by an angle ANG in degrees.
+    Rotates points counter-clockwise by an angle ANG in degrees.
     Michele cappellari, Paranal, 10 November 2013
 
     """
@@ -203,8 +148,8 @@ def rotate_points(x, y, ang):
 def psf_conv(x, y, inc_deg,
              surf_lum, sigma_lum, qobs_lum,
              surf_pot, sigma_pot, qobs_pot,
-             beta, gamma, kappa, moment, align, sigmaPsf, normPsf,
-             pixSize, pixAng, step, nrad, nang, nlos, epsrel):
+             beta, gamma, moment, align, sigmaPsf, normPsf,
+             pixSize, pixAng, step, nrad, nang, nlos, epsrel, interp):
     """
     This routine gives the velocity moment after convolution with a PSF.
     The convolution is done using interpolation of the model on a
@@ -242,7 +187,7 @@ def psf_conv(x, y, inc_deg,
 
     # Kernel step is 1/4 of largest value between sigma(min) and 1/2 pixel side.
     # Kernel half size is the sum of 3*sigma(max) and 1/2 pixel diagonal.
-    if (nrad*nang > x.size) and (not psf_convolution): # Just calculate values
+    if not interp or ((nrad*nang > x.size) and (not psf_convolution)): # Just calculate values
 
         x_pol = x
         y_pol = y
@@ -268,12 +213,16 @@ def psf_conv(x, y, inc_deg,
 
     # The model computation is only performed on the polar grid
     # which is then used to interpolate the values at any other location
-    model = proj_model(x_pol, y_pol, inc,
-                       dens_lum, sigma_lum, qintr_lum,
-                       dens_pot, sigma_pot, qintr_pot,
-                       beta, gamma, kappa, nrad, nang, nlos, epsrel, moment, align)
+    vel, vel2 = vmom_proj(x_pol, y_pol, inc,
+                          dens_lum, sigma_lum, qintr_lum,
+                          dens_pot, sigma_pot, qintr_pot,
+                          beta, gamma, nrad, nang, nlos, epsrel, align)
 
-    if psf_convolution:  # PSF convolution
+    model = {'xx': vel2[0, 0], 'yy': vel2[1, 1], 'zz': vel2[2, 2],
+             'xy': vel2[0, 1], 'xz': vel2[0, 2], 'yz': vel2[1, 2],
+             'x': vel[0], 'y': vel[1], 'z': vel[2]}[moment]
+
+    if interp and psf_convolution:  # PSF convolution
 
         nx = int(np.ceil(rmax/step))
         ny = int(np.ceil(rmax*qmed/step))
@@ -288,9 +237,9 @@ def psf_conv(x, y, inc_deg,
         model_car = mge_car*bilinear_interpolate(logRad, ang, model.reshape(nang, nrad), r1, e1)
 
         # Calculation was done in positive quadrant
-        if moment in ('xy', 'xz'):
+        if moment in ['xy', 'xz']:
             model_car *= np.sign(x_car*y_car)
-        elif moment in ('y', 'z'):
+        elif moment in ['y', 'z']:
             model_car *= np.sign(x_car)
         elif moment == 'x':
             model_car *= np.sign(y_car)
@@ -311,8 +260,11 @@ def psf_conv(x, y, inc_deg,
         kernel = kernel.sum(-1)   # Sum over PSF components
 
         # Seeing and aperture convolution with equation (A3) of Cappellari (2008)
-        muCar = signal.fftconvolve(model_car, kernel, mode='same') \
-              / signal.fftconvolve(mge_car, kernel, mode='same')
+        m1 = signal.fftconvolve(model_car, kernel, mode='same')
+        m2 = signal.fftconvolve(mge_car, kernel, mode='same')
+        w = m2 > 0   # Allow for rounding errors
+        muCar = np.zeros_like(m1)
+        muCar[w] = m1[w]/m2[w]
 
         # Interpolate convolved image at observed apertures.
         # Aperture integration was already included in the kernel.
@@ -320,7 +272,7 @@ def psf_conv(x, y, inc_deg,
 
     else:  # No PSF convolution
 
-        if nrad*nang > x.size:      # Just returns values
+        if not interp or (nrad*nang > x.size):      # Just returns values
             mu = model
         else:                      # Interpolate values
             r1 = 0.5*np.log(x**2 + (y/qmed)**2) # Log elliptical radius of input (x,y)
@@ -335,7 +287,7 @@ def psf_conv(x, y, inc_deg,
             elif moment == 'x':
                 mu *= np.sign(y)
 
-    return mu, psf_convolution
+    return mu, psf_convolution, vel, vel2
 
 ##############################################################################
 
@@ -368,16 +320,18 @@ class jam_axi_proj:
     .. code-block:: python
 
         jam = jam_axi_proj(
-                surf_lum, sigma_lum, qobs_lum, surf_pot, sigma_pot, qobs_pot,
-                inc, mbh, distance, xbin, ybin, beta=None, gamma=None,
-                errors=None, flux_obs=None, goodbins=None, ml=None,
-                nang=10, normpsf=1., nrad=20, pixang=0., pixsize=0.,
-                plot=True, quiet=False, kappa=None, rbh=0.01, data=None,
-                sigmapsf=0., step=0., moment='zz', vmax=None, vmin=None,
-                nlos=65, epsrel=1e-2, align='cyl', kwargs={})
+                 surf_lum, sigma_lum, qobs_lum, surf_pot, sigma_pot, qobs_pot,
+                 inc, mbh, distance, xbin, ybin, beta=None, gamma=None,
+                 errors=None, flux_obs=None, goodbins=None, kappa=None, ml=None,
+                 nang=10, normpsf=1., nrad=20, pixang=0., pixsize=0., plot=True,
+                 quiet=False, rbh=0.01, data=None, sigmapsf=0., step=0.,
+                 moment='zz', vmax=None, vmin=None, nlos=65, epsrel=1e-2,
+                 align='cyl', kwargs={})
 
         vrms = jam.model  # with moment='zz' the output is the LOS Vrms
 
+        jam.plot()   # Generate data/model comparison
+
     Input Parameters
     ----------------
 
@@ -392,10 +346,10 @@ class jam_axi_proj:
         typical units of ``Lsun/pc^2`` (solar luminosities per ``parsec^2``).
     sigma_lum: array_like with shape (n,)
         dispersion (sigma) in arcseconds of the MGE Gaussians describing the
-        kinematic-tracer population.
+        distribution of the kinematic-tracer population.
     qobs_lum: array_like with shape (n,)
         observed axial ratio (q') of the MGE Gaussians describing the
-        kinematic-tracer population.
+        distribution of the kinematic-tracer population.
     surf_pot: array_like with shape (m,)
         peak value of the MGE Gaussians describing the galaxy total-mass
         surface density in units of ``Msun/pc^2`` (solar masses per ``parsec^2``).
@@ -482,22 +436,32 @@ class jam_axi_proj:
 
         where ``velBin`` and ``sigBin`` are the velocity and dispersion in each
         bin and ``dVel`` and ``dSig`` are the corresponding uncertainties.
-        (Default: constant errors ``errors = 0.05*np.median(data)``)
+        (Default: constant ``errors = 0.05*np.median(data)``)
     flux_obs: array_like with shape (p,), optional
         Optional mean surface brightness of each bin for plotting.
     goodbins: array_like with shape (p,)
-        Boolean vector with values ``True`` for the bins which have to be
-        included in the fit (if requested) and ``chi**2`` calculation.
+        Boolean vector with values ``True`` for the bins/spaxels which have to
+        be included in the fit (if requested) and in the ``chi**2`` calculation.
         (Default: fit all bins).
+    interp: bool, optional
+        Set ``interp=False`` to force no-interpolation on the sky plane.
+        In this way ``jam.vel`` and ``jam.vel2`` contain all the first and
+        second velocity moments at the input coordinates ``(xbin, ybin)``.
+    kappa: float, optional
+        When ``kappa=None`` (default) the first velocity moments are scaled in
+        such a way that the projected angular momentum of the data and model is
+        the same (equation 52 of Cappellari 2008, MNRAS).
+        When ``kappa=1`` the model first velocity moments are output without
+        any scaling.
     ml: float, optional
         Mass-to-light ratio (M/L) to multiply the values given by ``surf_pot``.
         Setting this keyword is completely equivalent to multiplying the
         output ``model`` by ``np.sqrt(M/L)`` after the fit. This implies that
-        the BH mass becomes ``mbh*(M/L)``.
+        the BH mass is also scaled and becomes ``mbh*ml``.
 
-        If this keyword is not set or set to a negative number in input, the M/L
-        is fitted from the data and the best-fitting M/L is returned in the output.
-        The BH mass of the best-fitting model is ``mbh*(M/L)``.
+        If ``ml=None`` (default) the M/L is fitted from the data and the
+        best-fitting M/L is returned in output. The BH mass of the model is
+        also scaled and becomes ``mbh*ml``.
     nlos: int (optional)
         Number of values used for the numerical line-of-sight quadrature.
         (default ``nlos=65``)
@@ -507,10 +471,11 @@ class jam_axi_proj:
         The PSF will be used for seeing convolution of the model kinematics.
         It has to be ``np.sum(normpsf) = 1``.
     nang: int, optional
-        Same as for ``nrad``, but for the number of angular intervals.
+        The number of linearly-spaced intervals in the eccentric anomaly at
+        which the model is evaluated before interpolation and PSF convolution.
         (default: ``nang=10``)
     nrad: int, optional
-        The number of logarithmically spaced radial positions for which the
+        The number of logarithmically spaced radial positions at which the
         model is evaluated before interpolation and PSF convolution. One may
         want to increase this value if the model has to be evaluated over many
         orders of magnitude in radius (default: ``nrad=20``).
@@ -522,9 +487,10 @@ class jam_axi_proj:
         or lenslets of an integral-field spectrograph. This size is used to
         compute the kernel for the seeing and aperture convolution.
 
-        If this is not set, or ``pixsize=0``, then convolution is not performed.
+        If ``pixsize=None`` or ``pixsize=0`` then convolution is not performed.
     plot: bool
-        Set this keyword to produce a plot at the end of the calculation.
+        When ``data is not None`` setting this keyword produces a plot with the
+        data/model comparison at the end of the calculation.
     quiet: bool
         Set this keyword to avoid printing values on the console.
     rbh: float, optional
@@ -533,8 +499,6 @@ class jam_axi_proj:
         The gravitational potential is indistinguishable from a point source
         for ``radii > 2*rbh``, so the default ``rbh=0.01`` arcsec is appropriate
         in most current situations.
-
-        ``rbh`` should not be decreased unless actually needed!
     data: array_like with shape (p,), optional
         observed first or second velocity moment used to fit the model.
 
@@ -606,7 +570,7 @@ class jam_axi_proj:
     vmin: float, optional
         Minimum value of the ``data`` to plot.
     kwargs: dict, optioonal
-        Additional parameters passed to ``plotbin.plot_velfield``.
+        Additional keywords passed to ``plotbin.plot_velfield``.
 
     Output Parameters
     -----------------
@@ -620,24 +584,35 @@ class jam_axi_proj:
         tensor, or any of the three first velocity moments can be provided in
         output using the ``moment`` keyword.
     .ml: float
-        Best fitting M/L.
+        Best fitting M/L by which the mass was scaled to fit the observed moments.
     .chi2: float
         Reduced ``chi**2`` describing the quality of the fit::
 
-            chi2 = (((data[goodbins] - model[goodbins])/errors[goodbins])**2).sum()
-                 / goodbins.sum()
+            d, m = (data/errors)[goodbins], (model/errors)[goodbins]
+            chi2 = ((d - m)**2).sum()/goodbins.sum()
 
+        When no data are given in input, this is returned as ``np.nan``.
     .flux: array_like with shape (p,)
         PSF-convolved MGE surface brightness of each bin in ``Lsun/pc^2``,
         used to plot the isophotes of the kinematic-tracer on the model results.
+    .kappa: float
+        Ratio by which the model was scaled to fit the observed velocity
+        (equation 52 of Cappellari 2008, MNRAS)
+    .vel: array_like with shape (3, p)
+        First velocity moments for the x, y and z components.
+    .vel2: array_like with shape (3, 3, p)
+        Second velocity moment tensor. One has to set ``interp=False`` for this
+        to be computed at each input coordinate ``(xbin, ybin)``. If not, this
+        is just an intermediate result of the calculation, not intended for use.
+
 
     ###########################################################################
     """
     def __init__(self, surf_lum, sigma_lum, qobs_lum, surf_pot, sigma_pot, qobs_pot,
                  inc, mbh, distance, xbin, ybin, beta=None, gamma=None,
-                 errors=None, flux_obs=None, goodbins=None, ml=None,
-                 nang=10, normpsf=1., nrad=20, pixang=0., pixsize=0.,
-                 plot=True, quiet=False, kappa=None, rbh=0.01, data=None,
+                 errors=None, flux_obs=None, goodbins=None, interp=True,
+                 kappa=None, ml=None, nang=10, normpsf=1., nrad=20, pixang=0.,
+                 pixsize=0., plot=True, quiet=False, rbh=0.01, data=None,
                  sigmapsf=0., step=0., moment='zz', vmax=None, vmin=None,
                  nlos=65, epsrel=1e-2, align='cyl', **kwargs):
 
@@ -645,12 +620,11 @@ class jam_axi_proj:
         str2 =  ['xx', 'yy', 'zz', 'xy', 'xz', 'yz']
         assert moment in str1 + str2, f"`moment` must be one of {str1 + str2}"
         assert align in ['sph', 'cyl'], "`align` must be 'sph' or 'cyl'"
+        assert (ml is None) or (ml > 0), "The input `ml` must be positive"
         if beta is None:
             beta = np.zeros_like(surf_lum)  # Anisotropy parameter beta = 1 - (sig_th/sig_r)**2
         if gamma is None:
             gamma = np.zeros_like(surf_lum)  # Anisotropy parameter beta = 1 - (sig_th/sig_r)**2
-        if kappa is None:
-            kappa = np.ones_like(surf_lum)  # Anisotropy parameter: V_obs = kappa * V_iso (kappa=1-->circle)
         assert surf_lum.size == sigma_lum.size == qobs_lum.size == beta.size, "The luminous MGE components do not match"
         assert surf_pot.size == sigma_pot.size == qobs_pot.size, "The total mass MGE components do not match"
         assert xbin.size == ybin.size, "xbin and ybin do not match"
@@ -699,22 +673,15 @@ class jam_axi_proj:
         qobs_pot = qobs_pot.clip(0, 0.999)
 
         t = clock()
-        model, psfConvolution = psf_conv(
+        model, psfConvolution, vel, vel2 = psf_conv(
             xbin_pc, ybin_pc, inc,
             surf_lum_pc, sigma_lum_pc, qobs_lum,
             surf_pot_pc, sigma_pot_pc, qobs_pot,
-            beta, gamma, kappa, moment, align, sigmaPsf_pc, normpsf,
-            pixSize_pc, pixang, step_pc, nrad, nang, nlos, epsrel)
+            beta, gamma, moment, align, sigmaPsf_pc, normpsf,
+            pixSize_pc, pixang, step_pc, nrad, nang, nlos, epsrel, interp)
 
-        if not quiet:
-            print(f'jam_{align}_sph_rms elapsed time sec: %.2f' % (clock() - t))
-            if not psfConvolution:
-                txt = "No PSF convolution:"
-                if np.max(sigmapsf) == 0:
-                    txt += " sigmapsf == 0;"
-                if pixsize == 0:
-                    txt += " pixsize == 0;"
-                print(txt)
+        if moment in str2[:3]:
+            model = np.sqrt(model.clip(0))  # sqrt and clip to allow for rounding errors
 
         # Analytic convolution of the MGE model with an MGE circular PSF
         # using Equations (4,5) of Cappellari (2002, MNRAS, 333, 400).
@@ -725,90 +692,111 @@ class jam_axi_proj:
         flux = surf_conv[..., None]*np.exp(-0.5*(xbin**2/sigmaX2[..., None] + ybin**2/sigmaY2[..., None]))
         flux = flux.sum((0, 1))  # PSF-convolved Lsun/pc^2
 
-        if moment in str2[:3]:
+        if flux_obs is None:
+            flux_obs = flux
 
-            model = np.sqrt(model.clip(0))  # Return SQRT and fix possible rounding errors
+        if data is None:
 
-            if data is None:
-
-                chi2 = None
+            chi2 = np.nan
+            if moment in str2[:3]:
                 if ml is None:
-                    ml = 1.
+                    ml = kappa = 1.0
                 else:
                     model *= np.sqrt(ml)
+            else:
+                if kappa is None:
+                    ml = kappa = 1.0
+                else:
+                    model *= kappa
+
+        else:
+
+            d, m = (data/errors)[goodbins], (model/errors)[goodbins]
+
+            if moment in str2[:3]:
+
+                if ml is None:
+                    ml = ((d @ m)/(m @ m))**2   # eq. (51) of Cappellari (2008, MNRAS)
+
+                scale, kappa = np.sqrt(ml), 1.0
 
             else:
 
-                if (ml is None) or (ml <= 0):
-                    d, m = (data/errors)[goodbins], (model/errors)[goodbins]
-                    ml = ((d @ m)/(m @ m))**2   # eq. (51) of Cappellari (2008, MNRAS)
+                if kappa is None:
 
-                model *= np.sqrt(ml)
-                d, m, e, ok = data, model, errors, goodbins
-                chi2 = np.sum(((d[ok] - m[ok])/e[ok])**2)/ok.sum()
+                    # Scale by having the same angular momentum in the model and
+                    # in the galaxy with eq. (52) of Cappellari (2008, MNRAS)
+                    kappa = np.abs(data*xbin)[goodbins].sum()/np.abs(model*xbin)[goodbins].sum()
 
-                if not quiet:
-                    print(f'inc={inc:.1f} beta={beta[0]:.2f} M/L={ml:.3g} '
-                          f'BH={mbh*ml:.2e} chi2/DOF={chi2:.3g}')
-                    mass = 2*np.pi*surf_pot_pc*qobs_pot*sigma_pot_pc**2
-                    print(f'Total mass MGE: {np.sum(mass*ml):.4g}')
+                    # Measure the scaling one would have from a standard chi^2 fit of the V field.
+                    # This value is only used to get proper sense of rotation for the model.
+                    kappa1 = (d @ m)/(m @ m)  # eq. (51) of Cappellari (2008, MNRAS) not squared
+                    kappa *= np.sign(kappa1)
 
-        elif (moment in str1) and (data is not None):
+                scale, ml = kappa, 1.0
 
-            # Only consider the good bins for the chi**2 estimation
-            #
-            # Scale by having the same angular momentum
-            # in the model and in the galaxy (C08 equation 52)
-            #
-            kappa2 = np.sum(np.abs(data[goodbins]*xbin[goodbins])) \
-                     /np.sum(np.abs(model[goodbins]*xbin[goodbins]))
-            kappa = kappa*kappa2  # Rescale input kappa by the best fit
+            model *= scale
+            m *= scale
+            chi2 = ((d - m)**2).sum()/goodbins.sum()
 
-            # Measure the scaling one would have from a standard chi^2 fit of the V field.
-            # This value is only used to get proper sense of rotation for the model.
-            d, m = (data/errors)[goodbins], (model/errors)[goodbins]
-            kappa3 = (d @ m)/(m @ m)   # (C08 equation 51, not squared)
-
-            model *= kappa2*np.sign(kappa3)
-            chi2 = (((data[goodbins] - model[goodbins])/errors[goodbins])**2).sum()/goodbins.sum()
-
-            if not quiet:
-                print(f'inc={inc:.1f} kappa={kappa[0]:.2f} beta={beta[0]:.2f} '
-                      f'BH={mbh:.2e} chi2/DOF={chi2:.3g}')
-                mass = 2*np.pi*surf_pot_pc*qobs_pot*sigma_pot_pc**2
-                print('Total mass MGE %.4g:' % np.sum(mass))
-
-        if plot and (data is not None):
-
-            if flux_obs is None:
-                flux_obs = flux
-
-            sym = 1 if moment in str1 else 2
-            data1 = data.copy()  # Only symmetrize good bins
-            data1[goodbins] = symmetrize_velfield(xbin[goodbins], ybin[goodbins], data[goodbins], sym=sym)
-
-            if (vmin is None) or (vmax is None):
-                if (moment in str1) or (moment in ['xy', 'xz']):
-                    vmax = np.percentile(np.abs(data1[goodbins]), 99)
-                    vmin = -vmax
-                else:
-                    vmin, vmax = np.percentile(data1[goodbins], [0.5, 99.5])
-
-            plt.clf()
-            plt.subplot(121)
-            plot_velfield(xbin, ybin, data1, vmin=vmin, vmax=vmax, flux=flux_obs, **kwargs)
-            plt.title(f"Input V$_{{{moment}}}$ moment")
-
-            plt.subplot(122)
-            plot_velfield(xbin, ybin, model, vmin=vmin, vmax=vmax, flux=flux, **kwargs)
-            plt.plot(xbin[~goodbins], ybin[~goodbins], 'ok', mec='white')
-            plt.title(f"JAM$_{{\\rm{align}}}$ model")
-            plt.tick_params(labelleft=False)
-            plt.subplots_adjust(wspace=0.03)
+        if not quiet:
+            print(f'jam_axi_{align}_{moment}_proj elapsed time sec: {clock() - t:.2f}')
+            if not psfConvolution:
+                txt = "No PSF convolution:"
+                if np.max(sigmapsf) == 0:
+                    txt += " sigmapsf == 0;"
+                if pixsize == 0:
+                    txt += " pixsize == 0;"
+                print(txt)
+            print(f'inc={inc:.3g}; beta[0]={beta[0]:.2g}; kappa={kappa:.2g}; '
+                  f'M/L={ml:.3g}; BH={mbh*ml:.2g}; chi2/DOF={chi2:.3g}')
+            mass = 2*np.pi*surf_pot_pc*qobs_pot*sigma_pot_pc**2
+            print(f'Total mass MGE (MSun): {(mass*ml).sum():.4g}')
 
+        self.xbin = xbin
+        self.ybin = ybin
+        self.goodbins = goodbins
+        self.data = data
         self.model = model
         self.ml = ml
         self.chi2 = chi2
         self.flux = flux
+        self.flux_obs = flux_obs
+        self.kappa = kappa
+        self.moment = moment
+        self.align = align
+        self.vel = vel
+        self.vel2 = vel2
+
+        if plot and (data is not None):
+            self.plot(**kwargs)
+
+##############################################################################
+
+    def plot(self, **kwargs):
+
+        ok = self.goodbins
+        str1 = ['x', 'y', 'z']
+        sym = 1 if self.moment in str1 else 2
+        data1 = self.data.copy()  # Only symmetrize good bins
+        data1[ok] = symmetrize_velfield(self.xbin[ok], self.ybin[ok], data1[ok], sym=sym)
+
+        if self.moment in str1 + ['xy', 'xz']:
+            vmax = np.percentile(np.abs(data1[ok]), 99)
+            vmin = -vmax
+        else:
+            vmin, vmax = np.percentile(data1[ok], [0.5, 99.5])
+
+        plt.clf()
+        plt.subplot(121)
+        plot_velfield(self.xbin, self.ybin, data1, vmin=vmin, vmax=vmax, flux=self.flux_obs, **kwargs)
+        plt.title(f"Input V$_{{{self.moment}}}$ moment")
+
+        plt.subplot(122)
+        plot_velfield(self.xbin, self.ybin, self.model, vmin=vmin, vmax=vmax, flux=self.flux, **kwargs)
+        plt.plot(self.xbin[~ok], self.ybin[~ok], 'ok', mec='white')
+        plt.title(f"JAM$_{{\\rm{self.align}}}$ model")
+        plt.tick_params(labelleft=False)
+        plt.subplots_adjust(wspace=0.03)
 
 ##############################################################################
