@@ -251,8 +251,10 @@ def vrms2(x, y, inc_deg,
         r1 = 0.5*np.log(xCar**2 + (yCar/qmed)**2) # Log elliptical radius of cartesian grid
         e1 = np.arctan2(np.abs(yCar/qmed), np.abs(xCar))    # Eccentric anomaly of cartesian grid
 
-        wm2Car = bilinear_interpolate(logRad, ang, wm2Pol.reshape(nang, nrad), r1, e1)
+        # # Division by mgePol before interpolation reduces interpolation error
         mgeCar = mge_surf(xCar, yCar, surf_lum, sigma_lum, qobs_lum)
+        mgePol = mge_surf(xPol, yPol, surf_lum, sigma_lum, qobs_lum)
+        wm2Car = mgeCar*bilinear_interpolate(logRad, ang, (wm2Pol/mgePol).reshape(nang, nrad), r1, e1)
 
         if tensor in ('xy', 'xz'):
             wm2Car *= np.sign(xCar*yCar)  # Calculation was done in positive quadrant
