@@ -108,6 +108,8 @@ MODIFICATION HISTORY:
     V3.2.0: Replaced quadva with TAHN LOS quadrature (~4x speedup).
         MC, Oxford, 30 May 2019
     V3.2.1: Use analytic mge_surf in convolution. MC, Oxford, 31 October 2019
+    V3.2.2: Invert sign of V_x for consistency with Cappellari (2020) and
+        with the new jam_axi_proj. MC, Oxford, 22 July 2020
 
 """
 
@@ -245,7 +247,7 @@ def los_integrand(z1, dens_lum, sigma_lum, qintr_lum,
         integ = np.sqrt(nu*tmp.clip(0)) if kappa[0] > 0 else -np.sqrt((-nu*tmp).clip(0))
 
     if component == 'x':
-        f = y1*np.cos(inc) - z1*np.sin(inc)     # See Eq.(B9) of DR13
+        f = z1*np.sin(inc) - y1*np.cos(inc)     # See Eq.(B9) of DR13
     elif component == 'y':
         f = x1*np.cos(inc)                      # See Eq.(B8) of DR13
     elif component == 'z':
@@ -379,7 +381,7 @@ def vlos(x, y, inc_deg,
         # Division by mgePol before interpolation reduces interpolation error
         mgeCar = mge_surf(xCar, yCar, surf_lum, sigma_lum, qobs_lum)
         mgePol = mge_surf(xPol, yPol, surf_lum, sigma_lum, qobs_lum)
-        wm2Car = mgeCar*bilinear_interpolate(logRad, ang, (wmPol/mgePol).reshape(nang, nrad), r1, e1)
+        wmCar = mgeCar*bilinear_interpolate(logRad, ang, (wmPol/mgePol).reshape(nang, nrad), r1, e1)
 
         if component in ('y', 'z'):
             wmCar *= np.sign(xCar) # Calculation was done in positive quadrant
